/************************************************************************************************/
/*																								*/
/*	Module Name:	ListCAs																		*/
/*																								*/
/*	File Name:		ListCAs.c																	*/
/*																								*/
/*	 Apple Computer, Inc. 1991-1995															*/
/*	All Rights Reserved																			*/
/*																								*/
/*	Revision History:																			*/
/*																								*/
/*		Date		Who					Modification											*/
/*																								*/
/*		1991-07-16	Chris Halim			Original version										*/
/*		1995-06-26	Jaakko Railo		Version 2.0												*/
/*																								*/
/************************************************************************************************/

/****************************************** DESCRIPTION ******************************************

	This module calls TELCALookup to retrieve CAs allocated on the primary DN
	and list the current state of the CA.

*************************************************************************************************/

/******************************************** HEADERS *******************************************/

#include "TestModule.h"

/****************************************** DEFINITIONS *****************************************/

/****************************************** PROTOTYPES ******************************************/

short		GetCAState (TELCAHandle caHand);
void 		DoTest (CHRSPtr paramPtr);

/************************************************************************************************/
/************************************************************************************************/


pascal short TestModule (CHRSPtr paramPtr)
{
	short	returnValue = noErr;
	
	if (paramPtr->version <= kTestModuleVersion) {
		
		DoTest (paramPtr);
		
	}
	else
		returnValue = kWrongVersion;
		
	return (returnValue);
}


short	GetCAState (TELCAHandle caHand)
{
	OSErr	errCode;
	short	state;
	
	if ((errCode = TELGetCAState (caHand, &state)) != noErr)
		state = errCode;
	
	return (state);
}


void DoTest (CHRSPtr paramPtr)
{
	TELHandle	termHand = GetCurrentTELHandle (paramPtr);
	TELDNHandle	dnHand;
	TELCAHandle	caHand;
	OSErr		errCode;
	short		numOfCAs, index;
		
	if ((dnHand = GetDNHandle (paramPtr)) != nil) {
		numOfCAs = TELCountCAs (dnHand, telAllCallOrigins);
		Print (paramPtr, "Number of CAs found = %d", numOfCAs);
		
		for (index = 1; index <= numOfCAs; ++index) {
			if ((errCode = TELCALookup (dnHand, telAllCallOrigins, index, &caHand)) == noErr) {
				
				Print (paramPtr, "CA #%d = %08x, state = %d", index,
								caHand, GetCAState (caHand));
								
				if ((errCode = TELCADispose (caHand)) != noErr)
					Print (paramPtr, "### TELCADispose fails : %d", errCode);
			}
			else
				Print (paramPtr, "### TELCALookup fails : %d", errCode);
		}
	}
	else
		Print (paramPtr, "### Unable to retrieve the DN handle");
}


